# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/unittest_arena.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/protobuf/unittest_arena.proto',
  package='proto2_arena_unittest',
  syntax='proto2',
  serialized_options=b'\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$google/protobuf/unittest_arena.proto\x12\x15proto2_arena_unittest\"\x1a\n\rNestedMessage\x12\t\n\x01\x64\x18\x01 \x01(\x05\"U\n\x0c\x41renaMessage\x12\x45\n\x17repeated_nested_message\x18\x01 \x03(\x0b\x32$.proto2_arena_unittest.NestedMessageB\x03\xf8\x01\x01'
)




_NESTEDMESSAGE = _descriptor.Descriptor(
  name='NestedMessage',
  full_name='proto2_arena_unittest.NestedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='d', full_name='proto2_arena_unittest.NestedMessage.d', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=89,
)


_ARENAMESSAGE = _descriptor.Descriptor(
  name='ArenaMessage',
  full_name='proto2_arena_unittest.ArenaMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repeated_nested_message', full_name='proto2_arena_unittest.ArenaMessage.repeated_nested_message', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=176,
)

_ARENAMESSAGE.fields_by_name['repeated_nested_message'].message_type = _NESTEDMESSAGE
DESCRIPTOR.message_types_by_name['NestedMessage'] = _NESTEDMESSAGE
DESCRIPTOR.message_types_by_name['ArenaMessage'] = _ARENAMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NestedMessage = _reflection.GeneratedProtocolMessageType('NestedMessage', (_message.Message,), {
  'DESCRIPTOR' : _NESTEDMESSAGE,
  '__module__' : 'google.protobuf.unittest_arena_pb2'
  # @@protoc_insertion_point(class_scope:proto2_arena_unittest.NestedMessage)
  })
_sym_db.RegisterMessage(NestedMessage)

ArenaMessage = _reflection.GeneratedProtocolMessageType('ArenaMessage', (_message.Message,), {
  'DESCRIPTOR' : _ARENAMESSAGE,
  '__module__' : 'google.protobuf.unittest_arena_pb2'
  # @@protoc_insertion_point(class_scope:proto2_arena_unittest.ArenaMessage)
  })
_sym_db.RegisterMessage(ArenaMessage)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
